==> avidal-test-2-0.0.2.tgz: package/README.md <==
mynewcli
========



[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/mynewcli.svg)](https://npmjs.org/package/mynewcli)
[![Downloads/week](https://img.shields.io/npm/dw/mynewcli.svg)](https://npmjs.org/package/mynewcli)
[![License](https://img.shields.io/npm/l/mynewcli.svg)](https://github.com/vidalCreates/mynewcli/blob/master/package.json)

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Usage
<!-- usage -->
```sh-session
$ npm install -g avidal-test-2
$ avidal-test-2 COMMAND
running command...
$ avidal-test-2 (-v|--version|version)
avidal-test-2/0.0.2 win32-x64 node-v14.15.1
$ avidal-test-2 --help [COMMAND]
USAGE
  $ avidal-test-2 COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`avidal-test-2 hello [FILE]`](#avidal-test-2-hello-file)
* [`avidal-test-2 help [COMMAND]`](#avidal-test-2-help-command)

## `avidal-test-2 hello [FILE]`

describe the command here

```
USAGE
  $ avidal-test-2 hello [FILE]

OPTIONS
  -f, --force
  -h, --help       show CLI help
  -n, --name=name  name to print

EXAMPLE
  $ mynewcli hello
  hello world from ./src/hello.ts!
```

_See code: [src/commands/hello.ts](https://github.com/vidalCreates/avidal-test-2/blob/v0.0.2/src/commands/hello.ts)_

## `avidal-test-2 help [COMMAND]`

display help for avidal-test-2

```
USAGE
  $ avidal-test-2 help [COMMAND]

ARGUMENTS
  COMMAND  command to show help for

OPTIONS
  --all  see all commands in CLI
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v3.2.2/src/commands/help.ts)_
<!-- commandsstop -->

==> avidal-test-2-0.0.3.tgz: package/README.md <==
mynewcli
========



[![oclif](https://img.shields.io/badge/cli-oclif-brightgreen.svg)](https://oclif.io)
[![Version](https://img.shields.io/npm/v/mynewcli.svg)](https://npmjs.org/package/mynewcli)
[![Downloads/week](https://img.shields.io/npm/dw/mynewcli.svg)](https://npmjs.org/package/mynewcli)
[![License](https://img.shields.io/npm/l/mynewcli.svg)](https://github.com/vidalCreates/mynewcli/blob/master/package.json)

<!-- toc -->
* [Usage](#usage)
* [Commands](#commands)
<!-- tocstop -->
# Usage
<!-- usage -->
```sh-session
$ npm install -g avidal-test-2
$ avidal-test-2 COMMAND
running command...
$ avidal-test-2 (-v|--version|version)
avidal-test-2/0.0.3 win32-x64 node-v14.15.1
$ avidal-test-2 --help [COMMAND]
USAGE
  $ avidal-test-2 COMMAND
...
```
<!-- usagestop -->
# Commands
<!-- commands -->
* [`avidal-test-2 blah [FILE]`](#avidal-test-2-blah-file)
* [`avidal-test-2 help [COMMAND]`](#avidal-test-2-help-command)

## `avidal-test-2 blah [FILE]`

describe the command here

```
USAGE
  $ avidal-test-2 blah [FILE]

OPTIONS
  -f, --force
  -h, --help       show CLI help
  -n, --name=name  name to print

EXAMPLE
  $ mynewcli hello
  hello world from ./src/hello.ts!
```

_See code: [src/commands/blah.ts](https://github.com/vidalCreates/avidal-test-2/blob/v0.0.3/src/commands/blah.ts)_

## `avidal-test-2 help [COMMAND]`

display help for avidal-test-2

```
USAGE
  $ avidal-test-2 help [COMMAND]

ARGUMENTS
  COMMAND  command to show help for

OPTIONS
  --all  see all commands in CLI
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v3.2.2/src/commands/help.ts)_
<!-- commandsstop -->
